@@ -1,7 +1,7 @@
-from .density_estimation import KDE, KNeighborsDensity
+from .density_estimation import KNeighborsDensity
 from .xdeconv import XDGMM
+from .bayesian_blocks import bayesian_blocks
 from .histtools import\
     scotts_bin_width, freedman_bin_width, knuth_bin_width, histogram
-from .bayesian_blocks import bayesian_blocks
 from .empirical import FunctionDistribution, EmpiricalDistribution
 from .gauss_mixture import GaussianMixture1D
