@@ -3,17 +3,14 @@ SDSS Galaxy Colors
 ------------------
 The function :func:`fetch_sdss_galaxy_colors` used below actually queries
 the SDSS CASjobs server for the colors of the 50,000 galaxies.  Below we
-extract the :math:`u - g` and :math:`g - r` colors for 5000 stars, and
-scatter-plot the results
+extract the :math:`u - g` and :math:`g - r` colors for 5000 objects, and
+scatter-plot the results.
 """
 # Author: Jake VanderPlas <vanderplas@astro.washington.edu>
 # License: BSD
 #   The figure is an example from astroML: see http://astroML.github.com
-import numpy as np
 from matplotlib import pyplot as plt
 
-from sklearn.neighbors import KNeighborsRegressor
-
 from astroML.datasets import fetch_sdss_galaxy_colors
 
 #------------------------------------------------------------
@@ -26,8 +23,8 @@ ug = data['u'] - data['g']
 gr = data['g'] - data['r']
 spec_class = data['specClass']
 
-stars = (spec_class == 2)
-qsos = (spec_class == 3)
+galaxies = (spec_class == 'GALAXY')
+qsos = (spec_class == 'QSO')
 
 #------------------------------------------------------------
 # Prepare plot
@@ -37,7 +34,7 @@ ax = fig.add_subplot(111)
 ax.set_xlim(-0.5, 2.5)
 ax.set_ylim(-0.5, 1.5)
 
-ax.plot(ug[stars], gr[stars], '.', ms=4, c='b', label='stars')
+ax.plot(ug[galaxies], gr[galaxies], '.', ms=4, c='b', label='galaxies')
 ax.plot(ug[qsos], gr[qsos], '.', ms=4, c='r', label='qsos')
 
 ax.legend(loc=2)
